#!/bin/sh
export PATH='/usr/obj/hs-GLUT-2.5.1.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: GLUT
version: 2.5.1.1
id: GLUT-2.5.1.1-86b47e0dad63df8c5d8772ec45637472

license: BSD3
copyright:
maintainer: Sven Panne <svenpanne@gmail.com>, Jason Dagit <dagitj@gmail.com>
stability:
homepage: http://www.haskell.org/haskellwiki/Opengl
package-url:
synopsis: A binding for the OpenGL Utility Toolkit
description: A Haskell binding for the OpenGL Utility Toolkit, a window system independent
             toolkit for writing OpenGL programs. For more information about the C library
             on which this binding is based, please see:
             <http://www.opengl.org/resources/libraries/glut/>.
category: Graphics
author:
pkgpath: graphics/hs-GLUT
exposed: True
exposed-modules: Graphics.UI.GLUT Graphics.UI.GLUT.Begin
                 Graphics.UI.GLUT.Callbacks Graphics.UI.GLUT.Callbacks.Global
                 Graphics.UI.GLUT.Callbacks.Window Graphics.UI.GLUT.Colormap
                 Graphics.UI.GLUT.Debugging Graphics.UI.GLUT.DeviceControl
                 Graphics.UI.GLUT.Fonts Graphics.UI.GLUT.GameMode
                 Graphics.UI.GLUT.Initialization Graphics.UI.GLUT.Menu
                 Graphics.UI.GLUT.Objects Graphics.UI.GLUT.Overlay
                 Graphics.UI.GLUT.State Graphics.UI.GLUT.Window
hidden-modules: Graphics.UI.GLUT.Callbacks.Registration
                Graphics.UI.GLUT.QueryUtils Graphics.UI.GLUT.Raw
                Graphics.UI.GLUT.Raw.APIEntry Graphics.UI.GLUT.Raw.Callbacks
                Graphics.UI.GLUT.Raw.Fonts Graphics.UI.GLUT.Raw.Functions
                Graphics.UI.GLUT.Raw.Tokens Graphics.UI.GLUT.Types
trusted: False
import-dirs: /usr/local/lib/ghc/GLUT-2.5.1.1
library-dirs: /usr/local/lib/ghc/GLUT-2.5.1.1
hs-libraries: HSGLUT-2.5.1.1
extra-libraries: glut
extra-ghci-libraries:
include-dirs:
includes:
depends: OpenGL-2.9.2.0-3866a603e05ac9db9ad02ebb2d799a36
         OpenGLRaw-1.5.0.0-ecac437af724c8c90ed873a69fdf1787
         array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-GLUT-2.5.1.1/html/GLUT.haddock
haddock-html: /usr/local/share/doc/hs-GLUT-2.5.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
